modeltool --renametextures "D:\projects\oa\newbfg\Material" "models/weapons2/bfg/skin" *.md3
modeltool --renametextures "models/weapons2/bfg/skin" "models/weapons2/bfg/spinner" bfg_barrel.md3
modeltool --renametextures "D:\projects\oa\newbfg\bfgshot" "bfgShot" *.md3
modeltool --renametextures "D:\projects\oa\newbfg\bfgshot2" "bfgShot2" *.md3
