/*
===========================================================================
Copyright (C) 2007 Open Arena Team

This file is part of Open Arena.

Open Arena is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of the License,
or (at your option) any later version.

Open Arena is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Open Arena; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
===========================================================================
*/

#define MP_BACKGROUND "ui/assets/splash.jpg" // background of the menu
#define MP_SND_SELECT "sound/misc/menu1.wav" // confirm noise
#define MP_SND_HOVER "sound/misc/menu2.wav" // hover noise

#define MP_TITLECOLOR 1 1 1 1 // Title colors
#define MP_TEXTCOLOR  1 0 0 1 // regular color of menu button text
#define MP_FOCUSCOLOR 0 1 1 1 1 // focus 
#define MP_BOX_HEADERCOLOR 1 1 1 1 // for the text appearing above editboxes
#define MP_SMALLCOLOR 0.45 0.65 0 1 // the smaller options colors

#define MP_BOX_BORDER 	1 0 0 1
#define MP_BOX_FORE 	0.45   0.65  1   1
#define MP_BOX_BACK 	0.0 0.0 0.0 1
#define MP_BOX_OUTLINE 	1   0   0   0.3
