modeltool --renametextures "E:\projects\oa\newgib\Material" "ameatygib" *.md3
copy gib.md3 abdomen.md3
copy gib.md3 forearm.md3
copy gib.md3 skull.md3
copy gib.md3 brain.md3
copy gib.md3 fist.md3
copy gib.md3 chest.md3
copy gib.md3 intestines.md3
copy gib.md3 leg.md3
copy gib.md3 foot.md3
copy gib.md3 arm.md3