modeltool --renametextures "E:\projects\oa\newarmor\lambert2SG" "redArmor" *.md3
modeltool --renametextures "redArmor" "yellowArmor" yelarmor.md3
ren yelarmor.md3 armor_yel.md3
ren redarmor.md3 armor_red.md3