modeltool --renametextures "D:\projects\oa\newgauntlet\Material" "models/weapons2/gauntlet/skin" *.md3

modeltool --renametextures "models/weapons2/gauntlet/skin" "models/weapons2/gauntlet/saw" gauntlet_barrel.md3
