modeltool --renametextures "D:\projects\oa\newflag\Flag" "redFlag" r_flag.md3
modeltool --renametextures "D:\projects\oa\newflag\Flag" "blueFlag" b_flag.md3
modeltool --renametextures "D:\projects\oa\newflag\Sphere" "flagPole" *.md3
modeltool --renametextures "D:\projects\oa\newflag\lambert2SG" "flagPole" *.md3
