/*
===========================================================================
Copyright (C) 2006 Dmn_clown (aka: Bob Isaac (rjisaac@gmail.com))

This file is part of Open Arena and is based upon Mr. Elusive's fuzzy logic
system found in Quake 3 Arena.

Open Arena is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of the License,
or (at your option) any later version.

Open Arena is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Foobar; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
===========================================================================
*/

// group A sayings

DEATH_BFG0 = {
	"Is that all you've got?";
	"My grandmother hits harder than that.";
	"Lame.";
}

DEATH_BFG1 = {
	"I wish I sucked as much as you.";
	"Hoser!";
	"No-skill... none at all.";
}

DEATH_BFG2 = {
	"You wuss.";
	"Congratulations on your promotion to chief loser.";
	"Tell your mom to stop calling me.";
}

DEATH_BFG3 = {
	"Is this your first frag, ", 0, "?";
	"Now that was just rude.";
	"Ok, who gave ", 0," the new toy?";
}

DEATH_KAMIKAZE0 = {
	"Ya pansy!!!";
	"You have to admit that takes guts... oh wait...";
	"I hope your balls fall off in a freak fishing accident.";
	0, " sucks donkey balls!";
}

DEATH_KAMIKAZE1 = {
	"Cheap!";
	"So this is what death is like...";
	"Quick, painless, cheap.";
	"You can do better than that!";
}

DEATH_KAMIKAZE3 = {
	fighter, "s like you, ", 0, ", take the fun out of life.";
	"Oh, I get it.  You want to be left alone.";
	"Ok, who farted?";
	"What the hell was that all about?";
}

KILL_KAMIKAZE0 = {
	"That'll learn ya!";
	"pwnd";
	"Dodge that bitches!";
	"hehe... I farted.";
}

KILL_KAMIKAZE1 = {
	"Told ya so.";
	"I am all that is bot.";
	"Now that's what I call fun!";
	"D'oh!  Missed ", 0,".";
}


DEATH_INSULT0 = {
	"Life sucks, then you die, big deal.";
	"should have zagged instead of zigged.";
	"~I'm not impressed.";
	
}

DEATH_INSULT1 = {
	"I expected better from you.";
	"Lame.";
	"*tsk* you wasted too much ammo.";
	"This changes nothing, you still suck.";	
}

DEATH_INSULT2 = {
	"Can we get someone in here that isn't so cheesey?";
	"Didn't your mom tell you not to do that?";
	"Thanks, saved me the trouble.";
	"Is that all?";
}

DEATH_INSULT3 = {
	"Life is shit, and so are you.";
	"*sigh* if that only solved anything.";
	"Trying to impress someone?";
}
DEATH_INSULT4 = {
	"That was lame and you know it.";
	"Does ~your ", counselor, " know about your actions?";
	"big deal";
	"Can you say issues?  I knew you could.";
}

DEATH_INSULT5 = {
	"Obviously the only rational solution to your problem is suicide.";
	"Hehe... the safety was on.";
	"Scheisse";
	"Your ~mother.";
}

DEATH_FEM_INSULT0 = {
	"Typical, flat on my back and I can't feel a thing.";
	"You certainly know how to show a girl a good time... oh wait.";
	"That is not the best way to a girl's heart.";
	"The answer, ", 0, ", is still no.";
}

DEATH_FEM_INSULT1 = {
	"You can slap me around all you want, I still won't date you.";
	"I know all about violence against women...";
	"You are obviously a misogynist.";
	"~Men!";
}

DEATH_FEM_INSULT2 = {
	"Cute... Now go away before I have to slap a restraining order on you.";
	"Here I am flat on my back again... still no feeling.";
	"The best way to my heart is not through my chest...";
	"You know what they say the bigger the gun the smaller the...";
}

DEATH_FEM_INSULT3 = {
	"That is not going to get me to say yes.";
	"*NEWS FLASH* Women do not date misogynistic twits!";
	"Flat on my back... no feeling... just like last night.";
	"I can fake this too.";
}

DEATH_LAVA0 = {
	"Mmm... crispy.";
	"Note to self:  avoid red glowing stuff in the future.";
	"Hehe... oops";
	"So that is what happens...";
}

DEATH_LAVA1 = {
	"Ooops.";
	"I meant to do that.";
	"I was cold.";
	"I needed a break.";
}

DEATH_LAVA2 = {
	"Hey, ", fighter, ", care to join me?  It is nice and warm here.";
	"I did that to even the odds, ", 0, " needs the help.";
	"hot! hot! hot! hot! hot!";
	"*sigh*";
}

DEATH_SLIME0 = {
	"Note to self: avoid green glowing stuff in the future.";
	"Medic!";
	"Someone call maintenance we have a toxic spill down here!";
	"Has anyone reported this toxic spill to the EPA?";
}

DEATH_SLIME1 = {
	"Where is Ralph Nader when you need him?";
	"Someone call Sally Struthers!";
	"This is NOT a safe working environment, I want to talk to my Union Rep!";
	"This level needs an enema!";
}

DEATH_DROWN0 = {
	"Who needs air?";
	"Save me Jeebus!";
	"My ", counselor, " told me there would be days like this.";
	"When it is your time, it is your time... best to embrace it.";
}

DEATH_DROWN1 = {
	"Come on in the water is fi.. *glub*";
	"Hoo boy, how will I explain this?";
	"Did I mention that I can't swim?";
	"Never a life raft when you need one...";
}

DEATH_DROWN2 = {
	"I felt sorry for ", 0, " so I had to do it.";
	"Well... at least I'll be clean in the next life.";
	"Good bye cruel world.";
	"And I thought swimming was a useless skill... boy am I dumb.";
}

D_PRAISE0 = {
	"Nice shot.";
	"Care to show how that move is accomplished in slow motion?";
	"You are good.";
	"Nice 1";
}

D_PRAISE1 = {
	"The soft overcomes the hard, the slow overcomes the fast...";
	"The master arrives without leaving, sees without looking, achieves without doing... you are that ~one.";
	0, " is death incarnate... beware all ye ", fighter, "s.";
	"I have got to get me one of those...";
}

D_PRAISE2 = {
	"Wow! Even ", peeps, " ~can't top that.";	
	"I wish I was that good.";
	"Damn... how do you do that?";
	"Teach me how to do that, please.";
}

D_PRAISE3 = {
	"Do you think you could ease up and give the rest of us a chance?";
	"So... maybe I should just stay dead.";
	"So much for effort.";
	"Wow... I mean WOW!  That was a good shot!";
}

LEVEL_END0 = {
	"Sorry, I was goofin' on Elvis, what?";
	"So much for bluster...";
	"And the truth shall be revealed...";
	"I was robbed.";
	"gg";
		
}

LEVEL_END1 = {
	"good game";
	"nice ~one";
	"AGAIN!";
	"intense.";
	"that was a challenge.";
}

GOODBYE0 = {
	"Aww crap, I have an appointment with my ", counselor, " in ~15 minutes, gtg.  Bye.";
	"Aww man... my ", animal, " just peed on the carpet, gtg bye.";
	"Holy crap!  ", peeps, " is at my door... ttfn.";
	peeps, " has showed up, finally... later ~peeps!";
}

GOODBYE1 = {
	"My ", animal, " is begging to be let out, ttfn.";
	peeps, " is killing my ", animal, " gotta go stop it!";
	"ttfn";
	"Later tater";
}
	
GOODBYE2 = {
	"Adios ", friendname, ".";
	"~It's been real.";
	"Good god my bladder is full, later.";
	"Good bye";
}

GOODBYE3 = {
	"Holy crap! ", peeps, "is coming over at ", time, ampm, " and the place is a mess.  Got to clean.";
	"I have a meeting with ", peeps, " at ", time, ampm, " and I have to prepare, toodles.";
	"Au'revoir";
	"Time to call it a night, till we meet again.";
}
	
GOODBYE4 = {
	"'Till next time.";
	"Fare thee well.";
	"~It's been real and ~it's been fun...";
	"Time for me to jet.";
}

HELLO0 = {
	"Hello me lovlies!";
	"Are you ready to die, because you will.";
	"Greetings and salutations, now prepare to be fragged.";
	"Wake up... time to die!";
}

HELLO1 = {
	"Hey! Hey! Kids!";
	"What's shaking mi amigos?";
	"What's crack'a'lackin'?";
	"Hey ", fighter, "s time to get your groove on!";
}

HELLO2 = {
	"Yep.";
	"Hi-didly-ho neighbor.";
	"Yo sup dawg!";
	"'Sup G!";
}

HELLO3 = {
	"Wassuuppp!";
	"What is happening?"; //obvious dork greeting give a good response to this
	"Hello.";
	"Are you ready to rumble?";
}

HIT_NOKILL0 = {
	"Ha!";
	"Try taking the safety off";
	"It just isn't your day...";
	"Try harder";
}

HIT_NOKILL1 = {
	"You almost had me there... Not really, I just don't want you feeling bad.";
	"You almost don't suck.";
	"Try a real weapon next time.";
	"You try to hard... next time just do it.";
}

KILL_INSULT0 = {
	"Pathetic";
	"Looser";
	"hehe";
	"LOL!";
}

KILL_INSULT1 = {
	"Ha Ha!";
	"You should have stayed in bed this morning.";
	"Life's a game YOU cannot win...";
	"Another notch to my weapon belt.";
	"Heh, you suck.";
}

KILL_INSULT2 = {
	"Everyone I love is dead, why should you be any different?";
	"Did you think you were hot stuff?";
	"*tsk*";
	"Are you even trying?";
}

KILL_INSULT3 = {
	"Yet they say violence isn't necessary...";
	"Are you a fan of Ghandi?  Because non-violence will not work here.";
	number, " dollars says you don't get a frag this match.";
	"Man, ", 0," I thought with a name like yours you'd be a challenge.";
	"Lew-hoo-zer";
}

KILL_INSULT4 = {
	"That kinda looks painful, is it?";
	"It really isn't your day today...";
	"Stay down, you ", fighter, ", it will be easier on you.";
	"Oh just give up.";
	"You never quit, do you?";
	"Wow... your intestines kinda look like Richard Nixon stretched out like that.";
}

KILL_EXTREME_INSULT = {
	"If I were you... I'd kill myself";
	"Oh for the love of all that is good and holy, stay dead!";
	curse;
}

MISC0 = {
	"Wow I love the work they've done with ", 4, " much better than it was before.";
	"Anyone up for a game of raquetball after the match?";
	"Hey everyone... I think I just found an illegal wiretap.";
	"Do you think that violence in videogames is the cause of George W. Bush?";
}

MISC1 = {
	"Is there a point to it all?";
	"*sigh*";
	"I hate everyone.";
	"Yo, I just realized I can fart the Star Spangled Banner!";
}

MISC2 = {
	"Do you think world peace will ever be achieved?";
	"Is it wrong to want to blow people up?";
	"Aren't we all just dust in the wind?";
	"Yep.";
}

MISC3 = {
	"So... how about them Cubs?";
	"I heard that Microsoft was going to GPL their operating system."
	"~When will all people be treated equally?";
	"You know, if a man wants to marry an ", animal, ", Pat Robertson should allow it.";
	"You know, if a woman wants to marry an ", animal, ", Pat Robertson should allow it.";
}

MISC4 = {
	"Who's paying for the ", food, "?";
	4, " has good feng shei.";
	"Has anyone heard the new Metallica album?  Why don't they just retire already!?!";
	"Has anyone seen ", peeps, " around here?";
	"I feel stupid and contageous.";
}

GUYTALK0 = {
	femalebot, " is hot.";
	"Anyone up for a brew after the match?", 0, " is buying.";
	femalebot, " gave me ", disease, ".";
	"What do you think the Cubs chances are this year?";
}

GUYTALK1 = {
	"So, ", femalebot, " is there any chance for you and I?";
	"So, ", malebot, "is there any chance for you and I?";
	"Dude, pull my finger!";
	"Uh huh huh, who farted?";
}

GRRLTALK0 = {
	malebot, " gave me ", disease, ".";
	malebot, " is cute.";
	"Hold on my bra is pinching, ahh that is better.";
	"I wouldn't date ", malebot, " if he paid me.";
	0, " is kinda cute.";
}

GRRLTALK1 = {
	femalebot, " is cute.";
	"I'm thinking about getting implants, any thoughts?";
	"So ", 0, " when are you going to say something about my hair?";
	"I wouldn't date ", femalebot, " if she paid me.";
	0, ", do you douche?";
}

PRAISE0 = {
	"I am impressed.";
	"nice one.";
	"Keep it up, that was good.";
	"You've got some good moves there, ", 0, ".";
}

PRAISE1 = {
	"Not bad, you might get a medal... someday.";
	"Wow, you are good";
	"Impressive";
}

LEVEL_START0 = {
	"Oooh, I like ", 4, " always fun.";
	4, " again?  Sheesh someone cycle the maps!";
	"Ahh, ", 4, " my favorite place.";
	"I can remember ", 4, " before they screwed it up.";
}

LEVEL_START1 = {
	"Are you ", fighter, "s ready to die in ", 4, "?";
	"Dibs on the rocket launcher!";
	"Your shoelace is untied.";
	"Isn't that your ", family_member, " calling you?";
}

LEVEL_START2 = {
	"Wake up... Time to die!";
	fighter, "s the jig is up, as is your time in the arena.";
	"Oh just give it up, I've already won.";
	"You people must be gluttons for punishment.";
}

LEVEL_START3 = {
	4, " needs work, it is far to easy for me to frag you.";
	"Oh, here we go again, ", fighter, "s thinking they have a chance.";
	"Ooooh, ", 4, ".  FUN!";
	"*Everybody now!  'Come as you are, as you were, as I want you to be'...";
}

TAUNT0 = {
	"What's wrong can't you hit me?";
	"Guess what?  You still suck!";
	fighter, " just lay down and pretend to be dead...";
	"Is that the best you've got?";
}

TAUNT1 = {
	"*NEWS FLASH*, ", 0, " gave my ", family_member, " ", disease, ".";
	"Does your mother know how you spend your time?";
	"I wish I could be as lame as you.";
	"Oh just admit it, ", 0, " you think Visual Basic is a great language.";
}

TAUNT2 = {
	"The more you know, the less you understand.";
	"Have you had a coffin fitting yet?";
	"If only ", 0, " was a challenge...";
	"you ", fighter, ".";
}

TAUNT_FEM0 = {
	"You call that a gun?  HA!";
	"*Snif* ewww... too much testosterone.";
	"Put that thing away, do you want to go blind?";
	"Do you shave your palms?";
	"I hear that ", 0, " got ", disease, " from ", botnames, ".";
}

TELEFRAGGED0 = {
	"LOL!";
	"Aww man... I am so glad I don't have to clean that up.";
	"Eewww!";
	"Sorry but I had to practice my praetorian impression.";
	"Hi there, how's it going?";
}

TELEFRAGGED1 = {
	"Sucks to be you...";
	"and I just had my suit dry cleaned... jerk!";
	"Think of the cleaning bills this place must have...";
	"Gross";
}

TELEFRAGGED2 = {
	"Two's a crowd these days.";
	"That'll learn ya to keep your distance.";
	"HA!";
	"That was fun!";
	"What are the odds?";
}

DEATH_SUICIDE0 = {
	"Suicide is painless, it brings on many changes... I can take or leave it if I please.";
	"The game of life is hard to play, I'm going to lose it anyway...";
	"The sword of time will pierce our skins, it doesn't hurt when it begins.";
	"I hate life.";
	"At least I'm insured.";
}

DEATH_SUICIDE1 = {
	"I just couldn't take it anymore.";
	"I hate life.";
	"*sigh*";
	"Ooops";
	"Well, ", 0, " needed the help.";
}

DEATH_SUICIDE2 = {
 	"Good bye cruel arena!";
	"Take that IRS bastards!";
	"I hate my life.";
	"There go my insurance rates.";
}

KILL_RAIL0 = {
	"I love this gun!";
	"That looked painful.";
	"Dodge that!";
	"You never stood a chance.";
}

KILL_RAIL1 = {
	"Hehehe";
	"Sniping is not camping...";
	"Never saw it coming...";
}

DEATH_RAIL0 = {
	"Nice shot.";
	"Well, so much for that...";
	curse;
	"Does your ", family_member, " know how lame you are?";
}

DEATH_RAIL1 = {
	"son of a...";
	"*sigh*";
	"Oh well, camper's have rights too";
	"Can't hack it with a real weapon?";
}

KILL_GAUNTLET0 = {
	"LOL!";
	"pathetic";
	"One hand tied behind my back";
	"That'll learn ya";
}

KILL_GAUNTLET1 = {
	"Now shut up!";
	"That ought to shut you up.";
	"Humiliating, isn't it?";
	"Ouch!";
	"GAUNTLET KILL!";
}

DEATH_GAUNTLET0 = {
	"Don't touch me there!";
	"Eeww, I better get checked out for ", disease, " now.";
	"Unsanitary";
	"LOL!";
	"So much for bluster";
}

DEATH_GAUNTLET1 = {
	"How humiliating";
	"I have been shamed.";
	"I suck";
	"I can't believe I allowed that to happen.";
	"OMFNG";
}

DEATH_FALLING0 = {
	"I'm flying!  I'm flying! I'm *SPLAT*";
	"Look ~ma I can fly!";
	"Aww crap!";
	"hehe oops";
	"I meant to do that.";
	
}

DEATH_TELEFRAGGED0 = {
	"Praetorians suck!";
	"Get it out!  Get it out!";
	"*sigh*";
	"I am not amused";
}

DEATH_TELEFRAGGED1 = {
	"Glad I do not have your dry cleaning bill.";
	"I did not wish to become one with ", 0, ".";
	"I do not appreciate that.";
	curse;
	response_insult;
}

LEVEL_END_VICTORY0 = {
	"Yep.";
	"Situation Normal... I win again.";
	"Next time, don't bother.";
	"I told you so";
}

LEVEL_END_VICTORY1 = {
	"I'd like to thank my ", family_member, " and my ", counselor, " for this.";
	"When will you ", fighter, "s learn?  This is my game!";
	"Here I am again, at the top like it should be.";
	"I didn't even break a sweat.";
}

LEVEL_END_LOSE0 = {
	"I was robbed!";
	"gg, but look out for next time.";
	"You are going down next time.";
	"Two out of three?";
}

LEVEL_END_LOSE1 = {
	"I want a rematch!";
	"I demand a recount!";
	"My trigger finger cramped up.";
	"Oh no wonder, the safety was on...";
}

DEATH_TALKING = {
	"Son of a... DO YOU MIND!?!";
	"So much for holding a civil conversation...";
	"Sheesh, can't even attempt to be civil these days.";
	"That was very cheap";
}


// Group B sayings (fill in the blank style random sayings)


language = {
	"gibberish";
	"baby-talk";
	"Spanish";
	"Ebonics";
	"newspeak";
	"French";
	"Spanglish";
	"German";
	"Dutch";
	"Russian";
	"Maori";
	"Lakota";
	"Dineh";
	"Sanskrit";
	"Swahili";
}

weapon = {
	"gauntlet";
	"rocket launcher";
	"shotgun";
	"machine gun";
	"grenade launcher";
	"railgun";
	"plasmagun";
	"BFG";
	"BFG10K";
	"lightning gun";
}

ponder = {
	"why?";
	"Whats with politicians these days?"; //anarchist response
	"What is the meaning of it all?"; //buddhist response
	"Universal harmony, will it ever happen?  Discuss."; //taoist response
	"Jesus died for my sins?"; //sceptical response
	"If evolution is happening, why are people so stupid?";
	"Ever do any fishing?";
}

response_insult = {
	"No one cares, shut up!";
	"jackass";
	"That isn't what your ~mom said last night.";
	"If you had half a brain, you would be dangerous.";
	"idiot";
	"moron";
	"Oh for the love of Pete!  SHUT UP!";
	"Do the world a favor, pull your bottom lip over your head and swallow.";
	"Shut up, dick weed.";
	"dick head";
	"dipshit";
	"asswhipe";
	"fool";
	"jerkwad";
	
}

counselor = { 
	"school nurse";
	"astrologer";
	"shrink";
	"proctologist";
	"prostitute";
	"psychologist";
	"priest";
	"hair-stylist";
	"bar tender";
	"palm reader";
	"pediatrist";
	"nurse";
	"doctor";
	"spouse";
	"significant other";
	"goat-herd";
	"policeman";
	"policewoman";
	"congressman";
	"congresswoman";
}

family_member = {
	"mother";
	"father";
	"brother";
	"sister";
	"cousin";
	"aunt";
	"uncle";
	"brother-in-law";
	"sister-in-law";
	"wife";
	"husband";
	"son";
	"daughter";
	"grandmother";
	"grandfather";
	"great-uncle's cousin's half-sister";
	
}

friendname = {
	"mon ami";
	"mi amigo";
	"peepz";
	"comrades";
}


fighter = {
	"puke";
	"scum-bag";
	"snot face";
	"worthless bum";
	"gladiator";
	"whore";
	"pickle brain";
	"dweeb";
	"dork";
	"dickhead";
	"bastard";
	"asshole";
	"vomit-sucking ass licker";
	"blood sucker";
	
}



femalebot = {
	"Kyonshi";
	"Major";
	"Angelyss";
	"Ayumi";
	"Sly";
	"Dark";
	"Jenna";
	"Tanisha";
	"Rai";
	
}

malebot = {
	"Grism";
	"Gargoyle";
	"Merman";
	"Sergei";
	"Penguin";
	"Sarge";
	"Grunt";
	"Beret";
	"Tony";
}

neuterbot = {
	"Liz";
	"Arachna";
	"Widowe";
	"Skelebot";
}

botnames = {
	"Grism";
	"Gargoyle";
	"Kyonshi";
	"Major";
	"Merman";
	"Sergei";
	"Angelyss";
	"Penguin";
	"Liz";
	"Sarge";
	"Grunt";
	"Sly";
	"Dark";
	"Ayumi";
	"Jenna";
	"Arachna";
	"Widowe";
	"Tanisha";
	"Rai";
	"Skelebot";
	"Tony";
	"Beret";
}

negative = { 
	"Nada.";
	"no.";
	"nope";
	"In your dreams.";
	"Not just no, but hell no!";
}

affirmative = { 
	"sure";
	"why not?";
	"of course";
	"yes";
	"certainly";
	"absolutely";
}

neutral = { 
	"maybe";
	"I don't know";
	"perhaps";
	"I dunno";
	"possibly";
	
}

confused_response = {
	"Huh?";
	"Are you sure?";
	"I don't have an inkling about what you just said.";
	"Say what?";
	"Sorry, I do not speak ", language, ".";
	
}

number = { 
	"~one";
	"~two";
	"~three";
	"~four";
	"~five";
	"~six";
	"~seven";
	"~eight";
	"~nine";
	"~ten";
	"~11";
	"~12";
	"~13";
	"~14";
	"~15";
	"~16";
	"~17";
	"~18";
	"~19";
	"~20";
	"~100";
	"~150";
	"~200";
	"~1000";
	"a gagillion";
	"a googleplex";
}

profession = { 
	"police officer";
	"programmer";
	"level designer";
	"bum";
	"student";
}

disease = {
	"the clap";
	"HIV";
	"necrotising faceitus";
	"syphilus";
	"shingles";
	"chicken pox";
	"bird flue";
	"SARS";
	"elephantitis of the nose";
	"elephantitis of the ear";
	"flue";
	"whooping cough";
	"mono";
	"HPV";
}

peeps = { 
	"Lemmy Kilminster";
	"Johnny Rotton";
	"Jello Biafra";
	"Ozzy Osborne";
	"Jason Newstead";
	"Cliff Burton";
	"Your ~Mom";
	"Sigourney Weaver";
	"Pamela Anderson";
	"Carmen Elektra";
	"Dick Cheney";
	"Bill Frist";
	"dmn_clown";
	"Noam Chomsky";
	"Leo Tolstoy";
	"Trotsky";
	"Lao Tzu";
	"M. K. Ghandhi";
	"Tsun Tzu";
	"Jack Thompson";
	
}

immaturity01 = {
	"Why must I always end up on a server with morons?";
	"grow up";
	"childish";
	"Will this ignorance ever end?";
	"Thank you for being a supreme example of humanity.";
	"Wow, and I thought ", peeps, " was dumb.";
	
}

proposition01 = {
	"Sorry I've got a headache.";
	"No, your ", family_member, " told me that you have ", disease, ".";
	"No, I don't swing that way.";
	"I'm not into pimples.";
	"Sorry, I'm not ready for a relationship yet, but thanks for the offer.";
	"I'd rather go fishing";

}

whenf = { 
	"never";
	"tomorrow?";
	"where?";
	"Who's on first?";
	"in ", number, " millenia.";
	"yesterday";
	
}

whenp = { 
	"tomorrow";
	number, " days ago.";
	number, " years ago";
	peeps, " said ", number, " decades ago.";
	
}

time = { 
	"0:00";
	"1:00";
	"2:00";
	"3:00";
	"4:00";
	"5:00";
	"6:00";
	"7:00";
	"8:00";
	"9:00";
	"10:00";
	"11:00";
	"12:00";
	"1:30";
	"2:30";
	"3:30";
	"4:30";
	"5:30";
	"6:30";
	"7:30";
	"8:30";
	"9:30";
	"10:30";
	"11:30";
	"12:30";
	"0:15";
	"0:45";
	"1:15";
	"1:45";
	"2:15";
	"2:45";
	"3:15";
	"3:45";
	"4:15";
	"4:45";
	"5:15";
	"5:45";
	"6:15";
	"6:45";
	"7:15";
	"7:45";
	"8:15";
	"8:45";
	"9:15";
	"9:45";
	"10:15";
	"10:45";
	"11:15";
	"11:45";
}

ampm = {
	"AM";
	"PM";
}

food = { 
	"pizza";
	"cheeseburger";
	"tofu";
	"chicken";
	"monkey-brain";
	"goat-cheese";
	"roast beef";
	"liver";
}

animal = { 
	"goat";
	"simian";
	"mongoose";
	"pit-viper";
	"skunk";
	"cockroach";
	"dog";
	"cat";
	"hummingbird";
	"bumble bee";
	"sheep";
	"deer";
	"elk";
	"turkey";
	"squirrel";
	"ape";
	"duck-billed platypus";
	"spider";
	"small child";
	"beluga whale";
}

weather = { 
	"hot";
	"windy";
	"rainy";
	"snowing";
	"warm";
	"colder than a witch's left nipple";
	"hotter than your ~mom's panties";
}

month = { 
	"January";
	"February";
	"March";
	"April";
	"May";
	"June";
	"July";
	"August";
	"September";
	"October";
	"November";
	"December";
}

substance = { 
	"ink";
	"chalk";
	"salt";
	"pepper";
	"dog hair";
	"cayenne";
	"dog poo";
	"Janis Joplin's bra";
	"jock-cheese";
	
}


curse = {
	"I hope your genitals fall off in a freak fishing accident.";
	"May your first born child be born a politician...";
	"May your first born child be born with the intelligence of Pat Robertson.";
	"May you dream of leilol's ~mother for the rest of your rotten life!";
	"hum kah chan!";
}

vicious_insult = {
	"asshole";
	"jackass";
	"bigot";
	"worthless sack of shit";
	"waste of human space";
	"moron";
	"idiot";
	"bastard";
	"ho bag";
	"douche bag";
}
