modeltool --renametextures "D:\projects\oa\newoalogo\emblem" "logoEmblem" *.md3
modeltool --renametextures "D:\projects\oa\newoalogo\title" "logoTitle" *.md3
modeltool --renametextures "D:\projects\oa\newoalogo\halo" "logoHalo" *.md3
